function [surf_int_mean, surf_ht_mean, surf_E, surf_N, surf_H,surf_I] = surfacecalcs(tree_E,tree_N,tree_H, ...
    tree_I,max_crown_ht, cbh, grid_sz)
  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %Purpose:
    %This function takes descriptions of extents of point-cloud subset
    %(generally a tree crown or crown segment) and returns the height and
    %intensity of the highest points along the crown surface in a user-defined grid size.
    %This is useful for understanding the crown closure of a canopy.


    % Required arguments:
    % tree_E = (m,1) vector of eastings
    % tree_N = (m,1) vector of northings (of same points)
    % tree_H = (m,1) vector of heights (of same points)
    % tree_I = (m,1) vector of intensities (of same points)
    % max_crown_ht = max height of crown in question
    % cbh = crown base height of crown in question
    % 
    % Optional args:
    % grid_sz = size of grid over which to extract ht/int info. Default
    %           size is 0.5 m.
   
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  
%set defaults for optional arguments    
    if nargin < 7
        grid_sz = 0.5;
    elseif nargin < 6
        error('Too few arguments for surfacecalcs. Shameful.');
    end

%establish grid
    bins_EW = min(tree_E):grid_sz:max(tree_E);
    bins_NS = min(tree_N):grid_sz:max(tree_N);

     
%iterate through bins
  for j=1:length(bins_EW)-1  %E-W slices
      easting_range = bins_EW(j:j+1);

      idx_EW = find(tree_E >= easting_range(1) & tree_E < easting_range(2));

      for k=1:length(bins_NS)-1  %N-S bins in each E-W slice

          northing_range = bins_NS(k:k+1);
          idx_NS_EW = find(tree_N(idx_EW) >= northing_range(1) & tree_N(idx_EW)...
              < northing_range(2));

          %finds the highest point in the northing by easting bin that is
          %inside the crown max and min
          idx_z = find(tree_H(idx_EW(idx_NS_EW))<= max_crown_ht & tree_H(idx_EW(idx_NS_EW))>= ...
              cbh & tree_H(idx_EW(idx_NS_EW))== max(tree_H(idx_EW(idx_NS_EW))));

         %if the idx_z is not empty then grab the intensity value(s) for
         %the highest point(s)
          if ~isempty(idx_z)
            surf_holder(k,j) = mean(tree_I(idx_EW(idx_NS_EW(idx_z)))); %needs "mean" b/c there can be several same max heights
            surf_holder_max(k,j) = max(tree_I(idx_EW(idx_NS_EW(idx_z))));

            surf_H_holder(k,j) = mean(tree_H(idx_EW(idx_NS_EW(idx_z))));
            %COULD ADD IN SIMILAR VARIABLES TO HOLD HEIGHT VARIATION
            
            %store northings and eastings of highest point
            surf_E_holder(k,j) = mean(tree_E(idx_EW(idx_NS_EW(idx_z))));
            surf_N_holder(k,j) = mean(tree_N(idx_EW(idx_NS_EW(idx_z))));
            
          else
             surf_holder(k,j) = 0;

             surf_H_holder(k,j) = 0;
             surf_E_holder(k,j) = 0;
             surf_N_holder(k,j) = 0;
          end
          %b=b+1;
      end
  end
        surf_idx = find(surf_holder>0);

         %surf_int_pattern{i} = surf_holder; %saving for texture analysis
        surf_int_mean = mean2(surf_holder(surf_idx));
        surf_ht_mean = mean2(surf_H_holder(surf_idx));
        
        %report out location of high points
        dimE = size(surf_E_holder,1);
        dimN = size(surf_E_holder,2);
        surf_E = reshape(surf_E_holder,(dimE*dimN),1);
        surf_N = reshape(surf_N_holder,(dimE*dimN),1);
        surf_H = reshape(surf_H_holder,(dimE*dimN),1);
        surf_I = reshape(surf_holder,(dimE*dimN),1);
       
 end

 
  